@@ -19,6 +19,8 @@ from .functions import (
     get_referencing_foreign_keys,
     get_tables,
     group_foreign_keys,
+    has_any_changes,
+    has_changes,
     has_index,
     identity,
     merge_references,
@@ -68,7 +70,7 @@ from .types import (
 )
 
 
-__version__ = '0.26.2'
+__version__ = '0.26.3'
 
 
 __all__ = (
@@ -94,6 +96,8 @@ __all__ = (
     get_referencing_foreign_keys,
     get_tables,
     group_foreign_keys,
+    has_any_changes,
+    has_changes,
     has_index,
     identity,
     instrumented_list,
