@@ -26,6 +26,7 @@ from .orm import (
     get_primary_keys,
     get_tables,
     getdotattr,
+    has_any_changes,
     has_changes,
     identity,
     naturally_equivalent,
@@ -50,6 +51,7 @@ __all__ = (
     'get_tables',
     'getdotattr',
     'group_foreign_keys',
+    'has_any_changes',
     'has_changes',
     'identity',
     'is_auto_assigned_date_column',
